<?php

namespace Drupal\Tests\build_hooks\Kernel;

use Drupal\build_hooks\TriggerInterface;

/**
 * Defines a class for testing plugins can prevent builds.
 *
 * @group build_hooks
 */
class BuildTriggerTest extends BuildHooksKernelTestBase {

  /**
   * Tests a plugin can prevent a build.
   */
  public function testPreventBuildViaPlugin() {
    $this->assertFrontendEnvironmentBuildHook(
      'build_hooks_test',
      TriggerInterface::DEPLOYMENT_STRATEGY_ENTITYSAVE,
      NULL,
      ['whiz' => 'no deploy for you']
    );
  }

  /**
   * Tests a module can prevent a build.
   */
  public function testPreventBuildViaModule() {
    $this->assertFrontendEnvironmentBuildHook(
      'build_hooks_test',
      TriggerInterface::DEPLOYMENT_STRATEGY_ENTITYSAVE,
      NULL,
      ['whiz' => 'no deploy for you module']
    );
  }

  /**
   * Tests a plugin can prevent a build via access to entities in the deploy.
   */
  public function testAccessToDeployContents() {
    $this->assertFrontendEnvironmentBuildHook(
      'build_hooks_test',
      TriggerInterface::DEPLOYMENT_STRATEGY_ENTITYSAVE,
      NULL,
      ['whiz' => 'whang'],
      NULL,
      "can't let you do that dave"
    );
  }

}
